======
radicl
======


.. image:: https://img.shields.io/pypi/v/radicl.svg
        :target: https://pypi.python.org/pypi/radicl

.. image:: https://img.shields.io/travis/AdventureData/radicl.svg
        :target: https://travis-ci.org/AdventureData/radicl


.. image:: https://readthedocs.org/projects/radicl/badge/?version=latest
        :target: https://radicl.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Command line interface to the Realtime Adventure Data's Lyte probe for measuring avalanche conditions


* Free software: BSD license
* Documentation: https://radicl.readthedocs.io.
* Source code: https://github.com/AdventureData/radicl
* Website: https://adventuredata.com/


Features
--------

* Command line interface to the Lyte probe (radicl)
* Python API for interacting with the Lyte probe
* Commandline script for plotting profiles taken through the app (lyteplot)
* Open data processing!

Keep up to date
---------------

Keep up to date with our `researchers email list`_ where we email you when there
are new tools and updates available.

 .. _researchers email list: http://eepurl.com/geC1wD

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
